import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Button class is a general purpose button. It is a reusable module of code that utilizes abstraction in order to minimize
 * on the amount of classes created. A parameter is passed in the creation of the object in order to specify the type of
 * button that the button object will be. As a user would expect, the button is made to be pressed, and therefore has
 * actions that are carried out in the checkForClick() method dependent on the type of button it is.
 */
public class Button extends Actor
{
    /**
     * Button(String type) gets called whenever the class button is created. It is a general purpose button that is used
     * in lieu of several other button classes. Abstraction is used in order to have this one class responsible for
     * several purposes. The parameter String type allows for a string to be passed that specifies what button the object
     * will be. The only downside to using a string to specify the type of button is that the switch() statement does
     * not support strings in Java 6, and since Greenfoot still uses Java 6, the feature is unable to be used. Instead,
     * if and else if statements are used to specify the type of button.
     */
    private int i;
    private String type;
    private static int numberOfHumans = 1;
    public Button(String type)
    {
        this.type = type;
        if(type == "Singleplayer")
        {
            setImage("Singleplayer.png");
        }
        else if(type == "Multiplayer")
        {
            setImage("Multiplayer.png");
        }
        else if(type == "Help")
        {
            setImage("Help.png");
        }
        else if(type == "Exit")
        {
            setImage("Exit.png");
        }
        else if(type == "2")
        {
            setImage("Button2.png");
        }
        else if(type == "3")
        {
            setImage("Button3.png");
        }
        else if(type == "4")
        {
            setImage("Button4.png");
        }
        else if(type == "Start")
        {
            setImage("ButtonStart.png");
        }
    }

    public void act() 
    {
        if(Greenfoot.mouseClicked(this))
        {
            singleplayer();
            multiplayer();
            help();
            exit();
            button2();
            button3();
            button4();
            start();
        }
    }    

    private void singleplayer()
    {
        if(type == "Singleplayer")
        {
            for (Object o : getWorld().getObjects(IntroScreen.class)) //Returns a list of all the objects with name IntroScreen.class, should only be one
            {  
                IntroScreen in = (IntroScreen) o;  
                in.setFade(); //Makes the IntroScreen object fade
            }
        }
    }

    private void multiplayer()
    {
        if(type == "Multiplayer")
        {
            getWorld().addObject(new FullscreenImage("Multiplayer1"), 400, 300);
            getWorld().addObject(new Button("2"), 400, 300);
            getWorld().addObject(new Button("3"), 400, 400);
            getWorld().addObject(new Button("4"), 400, 500);
        }
    }

    private void help()
    {
        if(type == "Help")
        {
            getWorld().addObject(new FullscreenImage("Help"), 400, 300);
            getWorld().addObject(new Button("Exit"), 700, 546);
        }
    }
    
    private void exit()
    {
        if(type == "Exit")
        {
            Intro i = new Intro();
            Greenfoot.setWorld(i);
        }
    }
    
    private void button2()
    {
        if(type == "2")
        {
            numberOfHumans = 2;
            getWorld().addObject(new FullscreenImage("Multiplayer2"), 400, 300);
            getWorld().addObject(new Button("Start"), 400, 550);
        }
    }
    
    private void button3()
    {
        if(type == "3")
        {
            numberOfHumans = 3;
            getWorld().addObject(new FullscreenImage("Multiplayer2"), 400, 300);
            getWorld().addObject(new Button("Start"), 400, 550);
        }
    }
    
    private void button4()
    {
        if(type == "4")
        {
            numberOfHumans = 4;
            getWorld().addObject(new FullscreenImage("Multiplayer2"), 400, 300);
            getWorld().addObject(new Button("Start"), 400, 550);
        }
    }
    
    private void start()
    {
        if(type == "Start")
        {
            Level1 l = new Level1(numberOfHumans);
            Greenfoot.setWorld(l);
        }
    }
}
