import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color; //Allows for GreenfootImage to work properly, also allows for java.awt.Color data type to be used

/**
 * The Sidebar class controls the black bar on the right hand edge of the screen. It allows for the player/s to quickly glace on information such as 
 * their current level and powerups. It uses the TextDisplayer class in order to paint text on top of the Sidebar. 
 * 
 */
public class Sidebar extends Actor
{
    private Boolean levelStringNotDrawn = true; //Boolean that checks if the string that represents the level has been drawn, set to true by default
    private int level;
    private int numberOfHumans;
    private int score;
    private Boolean counterDown = false;
    //private Boolean rangeUp = false;
    private Boolean speedUp = false;
    private Boolean powerupsNotDrawn = true;
    private int deadPlayers;
    
    public Sidebar(int level, int numberOfHumans, int score)
    {
        this.level = level;
        this.numberOfHumans = numberOfHumans;
        this.score = score;
    }
    
    public void act(
    ) 
    {
        drawLevelString();
        addScoreBoard();
        drawPowerups();
    }    

    /**
     * drawLevelString() checks if the level string located at the top of the Sidebar has been drawn yet. If it has not been drawn, it will instantiate
     * the TextDisplayer class with parameters that make it suitable for displaying the text in the sidebar. The method then changes the
     * levelStringNotDrawn boolean to false in order to prevent the code from making more than one level string. The first parameter depicts the current
     * level, and also uses the currentLevel() method in order to get the current level that the world is on. The second parameter states the size of the
     * text, the third parameter states the foreground colour of the text, and the fourth parameter states the background colour of the text, in this
     * case, transparent (null). It then places the text at (700, 30) in the world.
     */
    private void drawLevelString()
    {
        if(levelStringNotDrawn == true) //Checks if the string has been drawn yet
        {
            getWorld().addObject(new TextDisplayer("Level " + currentLevel(), 25, Color.WHITE, null), 700, 30); //Instantiates the TextDisplayer class that displays the level
            levelStringNotDrawn = false; //Sets the boolean to false to prevent the string from being drawn more than once
        }
    }
    
    /**
     * currentLevel() returns a string that states the current level the player is on. It checks if the getWorld() command is a instance of one of the
     * possible levels, and if it is, it returns a value that is suitable to display in the drawLevelString() method. However, if the level is not
     * recognized, the system will print out an error and give instructions suitable to fixing the error. The instanceof operator checks if a method
     * is an instance of the levels.
     */
    private String currentLevel()
    {
        if(getWorld() instanceof Level1) //Checks if the getWorld() method is an instance of Level1, essentially checking if we are on the first level
        {
            return "1"; //Returns the string of "1"
        }
        else if(getWorld() instanceof Level2) //Checks if the getWorld() method is an instance of Level2, essentially checking if we are on the second level
        {
            return "2"; //Returns the string of "2"
        }
        else if(getWorld() instanceof Level3) //Checks if the getWorld() method is an instance of Level3, essentially checking if we are on the third level
        {
            return "3"; //Returns the string of "3"
        }
        else //Prints out a nice error message helpful for debugging if the Sidebar object is in a level that is not stated above
        {
            System.out.println("Error:");
            System.out.println("currentlevel() is broken in Sidebar class, world is not being recognised as valid");
            System.out.println("Perhaps the level has not been included in the class, or the level has changed name");
            return null; //Does not return a value
        }
    }
    
    /**
     * This method moves the objects and important variables (score, etc.) to the next world.
     */
    public void advanceLevel()
    {
        for(Object o : getWorld().getObjects(Counter.class))
        {
            Counter c = (Counter) o;
            score = c.getValue();
        }
        switch(level)
        {
            case 1:
                Level2 l = new Level2(numberOfHumans, score);
                Greenfoot.setWorld(l);
                break;
            case 2:
                Level3 m = new Level3(numberOfHumans, score);
                Greenfoot.setWorld(m);
                break;
            case 3:
                End n = new End(numberOfHumans, score, false);
                Greenfoot.setWorld(n);
                break;
        }
    }
    
    /**
     * This method adds a scoreboard if there isn't one already.
     */
    public void addScoreBoard()
    {
        if(counterDown == false)
        {
            getWorld().addObject(new Counter("Score: "), 700, 400);
            for(Object o : getWorld().getObjects(Counter.class))
            {
                Counter c = (Counter) o;
                c.setValue(score);
            }
            counterDown = true;
        }
    }
    
    /**
     * This method draws what powerups are currently being used.
     */
    private void drawPowerups()
    {
        if(powerupsNotDrawn == true)
        {
            getWorld().addObject(new TextDisplayer("Current Powerups:", 25, Color.WHITE, null), 700, 200);
        }
    }
    
    /**
     * This method allows the player classes to set what powerups they are using.
     */
    public void setPowerups(boolean rangeUp, boolean speedUp)
    {
        if(rangeUp == true)
        {
            getWorld().addObject(new TextDisplayer("Range up", 25, Color.WHITE, null), 700, 250);
        }
        if(speedUp == true)
        {
            getWorld().addObject(new TextDisplayer("Speed up", 25, Color.WHITE, null), 700, 300);
        }
    }
    
    /**
     * When all the players are dead, then we want to display a game over message.
     */
    public void deadPlayer()
    {
        deadPlayers++;
        if(deadPlayers >= numberOfHumans)
        {
            End m = new End(numberOfHumans, score, false);
            Greenfoot.setWorld(m);
        }
    }
}